@@ -21,6 +21,7 @@ The most commonly used commands are:
     check_fund_list         check fund list to get new funds and delisted funds
     dump_tables_and_dfs     dump all tables and dfs of fund dm to s3
     update_stock_factor     update stock factor and factor return
+    simple_check            check updating modules simply
 '''
 
 
@@ -123,12 +124,32 @@ class SurfingEntrance(object):
         return ViewDataProcessor().process_all(yesterday, yesterday)
 
     def dev_test(self):
-        import pandas as pd
-        from .data.fund.derived.derived_fund_manager_profit_processor import FundManagerProfitProcess, DerivedDataHelper
+        from .data.manager.stock_manager import StockDataManager
+        sdm = StockDataManager()
+        sdm.collect()
+        sdm.pickle_save()
 
-        date = '20200930'
-        fsg = FundManagerProfitProcess(DerivedDataHelper())
-        fsg.process(date, date, pd.to_datetime(date).date())
+    def simple_check(self):
+        print('to check surfing configurator')
+        from .util.config import SurfingConfigurator
+        # SurfingConfigurator is a singleton
+        _ = SurfingConfigurator(config_path='./etc/config.json')
+        print('check surfing configurator done')
+
+        print('to check raw data downloader')
+        from .data.fund.raw.raw_data_downloader import RawDataDownloader
+        # can not construct an object of RawDataDownloader
+        print('check raw data downloader done')
+
+        print('to check basic data downloader')
+        from .data.fund.basic.basic_data_processor import BasicDataProcessor
+        _ = BasicDataProcessor()
+        print('check basic data downloader done')
+
+        print('to check derived data downloader')
+        from .data.fund.derived.derived_data_processor import DerivedDataProcessor
+        _ = DerivedDataProcessor()
+        print('check derived data downloader done')
 
     def data_update(self):
         print('Start data update')
