@@ -32,6 +32,22 @@ class BasicDataApi(metaclass=Singleton):
             except Exception as e:
                 print(f'Failed to get data <err_msg> {e} from {TradingDayList.__tablename__}')
 
+    def is_today_trading_date(self):
+        today = datetime.datetime.now().date()
+        with BasicDatabaseConnector().managed_session() as db_session:
+            try:
+                query = db_session.query(
+                        TradingDayList
+                    ).filter(
+                        TradingDayList.datetime >= today,
+                    )
+                tag_df = pd.read_sql(query.statement, query.session.bind)
+                con = today in tag_df.datetime.tolist()
+                return con
+
+            except Exception as e:
+                print(f'Failed to get data <err_msg> {e} from {TradingDayList.__tablename__}')
+
     def get_last_trading_day(self, dt=datetime.datetime.today()):
         with BasicDatabaseConnector().managed_session() as db_session:
             try:
@@ -453,13 +469,13 @@ class BasicDataApi(metaclass=Singleton):
 
     def get_inside_market_funds(self):
         fund_status_latest = self.get_fund_status()
-        in_market_fund_list = fund_status_latest[~fund_status_latest['trade_status'].isnull()].fund_id.tolist()
+        in_market_fund_list = fund_status_latest[(~fund_status_latest['trade_status'].isnull()) & (fund_status_latest.trade_status != '终止上市')].fund_id.tolist()
         fund_info = self.get_fund_info()
         return fund_info[fund_info.fund_id.isin(in_market_fund_list)]
 
     def get_outside_market_funds(self):
         fund_status_latest = self.get_fund_status()
-        in_market_fund_list = fund_status_latest[~fund_status_latest['trade_status'].isnull()].fund_id.tolist()
+        in_market_fund_list = fund_status_latest[(~fund_status_latest['trade_status'].isnull()) & (fund_status_latest.trade_status != '终止上市')].fund_id.tolist()
         fund_info = self.get_fund_info()
         return fund_info[~fund_info.fund_id.isin(in_market_fund_list)]
 
@@ -821,6 +837,69 @@ class BasicDataApi(metaclass=Singleton):
                 print(f'Failed to get time range data <err_msg> {e} from {FundHoldStock.__tablename__}')
                 return
 
+    def get_fund_hold_stock_latest(self, dt=None, fund_list =[]) -> pd.DataFrame:
+        with BasicDatabaseConnector().managed_session() as db_session:
+            try:
+                if not dt:
+                    dt = db_session.query(
+                        func.max(FundHoldStock.datetime)
+                    ).one_or_none()
+                    if dt:
+                        dt = dt[0]
+
+                query = db_session.query(
+                    FundHoldStock
+                ).filter(
+                    FundHoldStock.datetime == dt,
+                    FundHoldStock.fund_id.in_(fund_list),
+                )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'Failed to get time range data <err_msg> {e} from {FundHoldStock.__tablename__}')
+                return
+
+    def get_fund_hold_bond_latest(self, dt=None, fund_list =[]) -> pd.DataFrame:
+        with BasicDatabaseConnector().managed_session() as db_session:
+            try:
+                if not dt:
+                    dt = db_session.query(
+                        func.max(FundHoldBond.datetime)
+                    ).one_or_none()
+                    if dt:
+                        dt = dt[0]
+
+                query = db_session.query(
+                    FundHoldBond
+                ).filter(
+                    FundHoldBond.datetime == dt,
+                    FundHoldBond.fund_id.in_(fund_list),
+                )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'Failed to get time range data <err_msg> {e} from {FundHoldBond.__tablename__}')
+                return
+
+    def get_fund_hold_asset_latest(self, dt=None, fund_list = []) -> pd.DataFrame:
+        with BasicDatabaseConnector().managed_session() as db_session:
+            try:
+                if not dt:
+                    dt = db_session.query(
+                        func.max(FundHoldBond.datetime)
+                    ).one_or_none()
+                    if dt:
+                        dt = dt[0]
+
+                query = db_session.query(
+                        FundHoldAsset
+                        ).filter(
+                            FundHoldAsset.datetime == dt,
+                            FundHoldAsset.fund_id.in_(fund_list),
+                        )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'Failed to get time range data <err_msg> {e} from {FundHoldAsset.__tablename__}')
+                return
+
     def delete_fund_hold_stock(self, date_to_delete: datetime.date, fund_list: List[str]):
         with BasicDatabaseConnector().managed_session() as db_session:
             try:
@@ -892,6 +971,21 @@ class BasicDataApi(metaclass=Singleton):
                 print(f'Failed to get time range data <err_msg> {e} from {FundStockPortfolio.__tablename__}')
                 return
 
+    def get_fund_stock_concept(self, tag_group_id_list: List[str]):
+        with BasicDatabaseConnector().managed_session() as db_session:
+            try:
+                query = db_session.query(
+                    StockTag
+                )
+                if tag_group_id_list:
+                    query = query.filter(
+                        StockTag.tag_group_id.in_(tag_group_id_list)
+                    )
+                return pd.read_sql(query.statement, query.session.bind).drop(columns=['_update_time'])
+            except Exception as e:
+                print(f'Failed to get_fund_stock_concept <err_msg> {e} from {StockTag.__tablename__}')
+                return
+
     def delete_fund_rate(self, date_to_delete: datetime.date, fund_list: List[str]):
         with BasicDatabaseConnector().managed_session() as db_session:
             try:
