@@ -3,7 +3,7 @@ import datetime
 from typing import List, Tuple, Union
 import pandas as pd
 from sqlalchemy.sql import func
-
+from sqlalchemy import or_
 from ...util.singleton import Singleton
 from ..wrapper.mysql import RawDatabaseConnector
 from ..view.raw_models import *
@@ -285,6 +285,47 @@ class RawDataApi(metaclass=Singleton):
                 print(f'Failed to get data <err_msg> {e} from {EmFundNav.__tablename__}')
                 return None
 
+    def get_oversea_fund_nav(self, start_date: str = '', end_date: str = '', fund_ids: Tuple[str] = (), columns: Tuple[str] = ()):
+        with RawDatabaseConnector().managed_session() as db_session:
+            try:
+                if not columns:
+                    query = db_session.query(
+                        OSFundNav
+                    )
+                else:
+                    query = db_session.query(
+                        OSFundNav.codes,
+                        OSFundNav.datetime,
+                    ).add_columns(*columns)
+                if fund_ids:
+                    query = query.filter(
+                        OSFundNav.codes.in_(fund_ids),
+                    )
+                if start_date:
+                    query = query.filter(
+                        OSFundNav.datetime >= start_date,
+                    )
+                if end_date:
+                    query = query.filter(
+                        OSFundNav.datetime <= end_date,
+                    )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'Failed to get data <err_msg> {e} from {OSFundNav.__tablename__}')
+                return None
+
+    def get_over_sea_fund_info(self):
+        with RawDatabaseConnector().managed_session() as db_session:
+            try:
+                query = db_session.query(
+                    OSFundInfo
+                )
+                df = pd.read_sql(query.statement, query.session.bind)
+                return df
+            except Exception as e:
+                print('Failed to get data <err_msg> {}'.format(e))
+                return None
+
     def delete_em_fund_nav(self, start_date, end_date):
         with RawDatabaseConnector().managed_session() as db_session:
             try:
@@ -1198,6 +1239,19 @@ class RawDataApi(metaclass=Singleton):
             except Exception as e:
                 print(f'Failed to get data <err_msg> {e} from {EmStockDividend.__tablename__}')
 
+    def get_em_stock_dividend_by_id(self, stock_id: str = ''):
+        with RawDatabaseConnector().managed_session() as raw_session:
+            try:
+                query = raw_session.query(EmStockDividend)
+                if stock_id:
+                    query = query.filter(
+                        EmStockDividend.CODES == stock_id,
+                    )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'Failed to get_em_stock_dividend_by_id <err_msg> {e} from {EmStockDividend.__tablename__}')
+                return pd.DataFrame([])
+
     def get_em_bond_info(self):
         with RawDatabaseConnector().managed_session() as raw_session:
             try:
@@ -1403,3 +1457,337 @@ class RawDataApi(metaclass=Singleton):
                 print(f'Failed to get_em_industry_info <err_msg> {e} from {EmIndustryInfo.__tablename__}')
                 return pd.DataFrame([])
 
+    def get_em_stock_balance(self, stock_id=None, columns: Tuple[str] = ()):
+        with RawDatabaseConnector().managed_session() as db_session:
+            try:
+                query = db_session.query(
+                    EmStockFSBalanceSheet,
+                )
+                if stock_id:
+                    query = query.filter(
+                        EmStockFSBalanceSheet.CODES == stock_id,
+                    )
+                if columns:
+                    query = query.add_columns(*columns)
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'Failed to get_em_stock_balance <err_msg> {e} from {EmStockFSBalanceSheet.__tablename__}')
+                return pd.DataFrame([])
+
+    def get_em_stock_income(self, stock_id=None, columns: Tuple[str] = ()):
+        with RawDatabaseConnector().managed_session() as db_session:
+            try:
+                query = db_session.query(
+                    EmStockFSIncomeStatement,
+                )
+                if stock_id:
+                    query = query.filter(
+                        EmStockFSIncomeStatement.CODES == stock_id,
+                    )
+                if columns:
+                    query = query.add_columns(*columns)
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'Failed to get_em_stock_income <err_msg> {e} from {EmStockFSIncomeStatement.__tablename__}')
+                return pd.DataFrame([])
+
+    def get_em_stock_income_quarterly(self, stock_id=None, columns: Tuple[str] = ()):
+        with RawDatabaseConnector().managed_session() as db_session:
+            try:
+                query = db_session.query(
+                    EmStockFSIncomeStatementQ,
+                )
+                if stock_id:
+                    query = query.filter(
+                        EmStockFSIncomeStatementQ.CODES == stock_id,
+                    )
+                if columns:
+                    query = query.add_columns(*columns)
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'Failed to get_em_stock_income_quarterly <err_msg> {e} from {EmStockFSIncomeStatementQ.__tablename__}')
+                return pd.DataFrame([])
+
+    def get_em_stock_cash_flow(self, stock_id=None, columns: Tuple[str] = ()):
+        with RawDatabaseConnector().managed_session() as db_session:
+            try:
+                query = db_session.query(
+                    EmStockFSCashflowStatement,
+                )
+                if stock_id:
+                    query = query.filter(
+                        EmStockFSCashflowStatement.CODES == stock_id,
+                    )
+                if columns:
+                    query = query.add_columns(*columns)
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'Failed to get_em_stock_cash_flow <err_msg> {e} from {EmStockFSCashflowStatement.__tablename__}')
+                return pd.DataFrame([])
+
+    def get_em_stock_cash_flow_quarterly(self, stock_id=None, columns: Tuple[str] = ()):
+        with RawDatabaseConnector().managed_session() as db_session:
+            try:
+                query = db_session.query(
+                    EmStockFSCashflowStatementQ,
+                )
+                if stock_id:
+                    query = query.filter(
+                        EmStockFSCashflowStatementQ.CODES == stock_id,
+                    )
+                if columns:
+                    query = query.add_columns(*columns)
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'Failed to get_em_stock_cash_flow_quarterly <err_msg> {e} from {EmStockFSCashflowStatementQ.__tablename__}')
+                return pd.DataFrame([])
+
+    def get_em_conv_bond_info(self):
+        with RawDatabaseConnector().managed_session() as db_session:
+            try:
+                query = db_session.query(
+                    EmConvBondInfo,
+                )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'Failed to get_em_conv_bond_info <err_msg> {e} from {EmConvBondInfo.__tablename__}')
+                return pd.DataFrame([])
+
+    def get_em_stock_ipo_recent(self, dt):
+        with RawDatabaseConnector().managed_session() as db_session:
+            col_dic = {
+                'IPOPRICE':'发行价',
+                'IPOISSUEDATE':'首发发行日期',
+                'IPOSHARESVOL':'首发数量',
+                'IPOPE':'发行市盈率',
+                'NAME':'股票简称',
+                'SUCRATIOONL':'中签率',
+                'PURCHACODEONL':'申购代码带市场',
+                'CEILINGONL':'申购上限',
+                'EMIND2016':'东财行业',
+                'TRADEMARKET':'上市板块',
+                'IPOPURCHDATEONL':'申购日期',
+                'IPOANNCDATE':'发行公告日',
+                'WSZQJGGGDATE':'中签公布',
+                'LISTDATE':'上市日期',
+                'CODES':'股票代码',
+            }            
+            try:
+                query = db_session.query(
+                    EmStockIpoInfo,
+                ).filter(
+                    or_(
+                            EmStockIpoInfo.IPOPURCHDATEONL >= dt,
+                            EmStockIpoInfo.LISTDATE >= dt,
+                            EmStockIpoInfo.WSZQJGGGDATE == dt,
+                            EmStockIpoInfo.LISTDATE == None,
+                    )
+                )
+                df = pd.read_sql(query.statement, query.session.bind).drop(columns=['_update_time','ISSUEAMTONL','LOTNUM','COMPROFILE','BUSINESS']).rename(columns=col_dic)
+                
+                df.loc[:,'接口种类'] = ''
+                df.loc[(df['上市日期'] > dt) | (df['上市日期'].isnull()),'接口种类']='未上市'
+                df.loc[df['申购日期'] == dt,'接口种类']='今日申购'
+                df.loc[df['上市日期'] == dt,'接口种类']='今日上市'
+                df.loc[df['中签公布'] == dt,'接口种类']='今日公布中签'
+                df.loc[df['申购日期'] > dt,'接口种类']='即将发行'
+                df.loc[:,'申购代码'] = df.申购代码带市场.map(lambda x : x.split('.')[0] if x is not None else None)
+                return df
+
+            except Exception as e:
+                print(f'Failed to get_em_stock_ipo_recent <err_msg> {e} from {EmStockIpoInfo.__tablename__}')
+                return pd.DataFrame([])
+
+    def get_em_conv_bond_ipo_recent(self, dt):
+        with RawDatabaseConnector().managed_session() as db_session:
+            col_dic = {
+                'CODES':'转债代码',
+                'CBCODE' : '转债代码无市场',
+                'CBNAME' : '转债简称',
+                'CBSTOCKCODE':'正股代码',
+                'CBSTOCKNAME':'正股简称',
+                'CBISSUEAMT':'发行规模',
+                'IPOANNCDATE':'发行公告日',
+                'CBIPOTYPE':'发行方式',
+                'CBPURCODEONL':'申购代码',
+                'ISSRATE':'发行时债项评级',
+                'CBTERM':'发行期限',
+                'CBISSUEPRICE':'发行价格',
+                'ISSUEONLEDATE':'发行截止日期',
+                'CBCONVPRICE':'转股价',
+                'CBDATEONL':'申购日期',
+                'CBLISTDATE':'上市日期',
+                'CBRESULTDATE':'中签公布',
+                'CBSUCRATEONL':'中签率',
+                'QUANTLIMITINTRO':'申购数量限制说明',   
+            }
+            try:
+                query = db_session.query(
+                    EmConvBondIpoInfo,
+                ).filter(
+                    or_(
+                            EmConvBondIpoInfo.CBDATEONL >= dt,
+                            EmConvBondIpoInfo.CBLISTDATE >= dt,
+                            EmConvBondIpoInfo.CBRESULTDATE == dt,
+                            EmConvBondIpoInfo.CBLISTDATE == None,
+                    ),
+                    EmConvBondIpoInfo.CBIPOTYPE == '公募',
+                )
+                df = pd.read_sql(query.statement, query.session.bind).drop(columns=['_update_time','CBMATURITYDATE','CBREDEMPRICETM','CBRATIONCODE','CBSUCCESS','CBPUTBACKPRICEEXPLAIN','CBREDEMMEMO']).rename(columns=col_dic)
+                df.loc[:,'接口种类'] = None
+                df.loc[((df['上市日期'] > dt) | (df['上市日期'].isnull())) & (df['发行方式']=='公募'),'接口种类']='未上市'
+                df.loc[df['申购日期'] == dt,'接口种类']='今日申购'
+                df.loc[df['上市日期'] == dt,'接口种类']='今日上市'
+                df.loc[df['中签公布'] == dt,'接口种类']='今日公布中签'
+                df.loc[df['申购日期'] > dt,'接口种类']='即将发行'
+                
+                df.loc[:,'申购上限'] = df.申购数量限制说明.map(lambda x: int(x.split('网上申购数量上限：')[1].split('手')[0]) * 10)
+                df.loc[:,'stock_id'] = df.正股代码 + '.' +df.转债代码.map(lambda x: x.split('.')[1])
+                df.loc[:,'申购代码带市场'] = df.申购代码 + '.' +df.转债代码.map(lambda x: x.split('.')[1])
+                df = df.dropna(subset=['接口种类'])
+                stock_price = self.get_em_stock_price_recent(df.stock_id.tolist())
+                df = pd.merge(df, stock_price[['close','stock_id']], on='stock_id').drop(columns=['stock_id']).rename(columns={'close':'正股价'})
+                return df
+
+            except Exception as e:
+                print(f'Failed to get_em_conv_bond_ipo_recent <err_msg> {e} from {EmConvBondIpoInfo.__tablename__}')
+                return pd.DataFrame([])
+
+    def get_em_stock_price_recent(self, codes: Tuple[str] = ()):
+        with RawDatabaseConnector().managed_session() as db_session:
+            try:
+                dt = db_session.query(
+                    func.max(EmStockPrice.DATES)
+                ).one_or_none()
+
+                query = db_session.query(
+                    EmStockPrice.CODES,
+                    EmStockPrice.DATES,
+                    EmStockPrice.CLOSE,
+                )
+                if codes:
+                    query = query.filter(
+                        EmStockPrice.CODES.in_(codes),
+                        EmStockPrice.DATES == dt[0],
+                    )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'Failed to get_em_stock_price_recent <err_msg> {e} from {EmStockPrice.__tablename__}')
+                return pd.DataFrame([])
+
+    def get_em_conv_bond_dirty_price(self, codes: Tuple[str] = ()):
+        with RawDatabaseConnector().managed_session() as db_session:
+            try:
+                query = db_session.query(
+                    EmConvBondDirtyPrice.CODES,
+                    EmConvBondDirtyPrice.DATES,
+                    EmConvBondDirtyPrice.CLOSE,
+                    EmConvBondDirtyPrice.OPEN,
+                )
+                if codes:
+                    query = query.filter(
+                        EmConvBondDirtyPrice.CODES.in_(codes),
+                    )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'Failed to get_em_conv_bond_dirty_price <err_msg> {e} from {EmConvBondDirtyPrice.__tablename__}')
+                return pd.DataFrame([])
+
+    def get_em_stock_ipo_info(self):
+        with RawDatabaseConnector().managed_session() as db_session:
+            col_dic = {
+                'IPOPRICE':'发行价',
+                'IPOISSUEDATE':'首发发行日期',
+                'IPOSHARESVOL':'发行总数',
+                'IPOPE':'发行市盈率',
+                'NAME':'股票简称',
+                'SUCRATIOONL':'中签率',
+                'PURCHACODEONL':'申购代码带市场',
+                'CEILINGONL':'申购数量上限',
+                'EMIND2016':'东财行业',
+                'TRADEMARKET':'上市板块',
+                'IPOPURCHDATEONL':'申购日期',
+                'IPOANNCDATE':'发行公告日',
+                'WSZQJGGGDATE':'中签公布',
+                'LISTDATE':'上市日期',
+                'CODES':'股票代码',
+                'ISSUEAMTONL':'网上发行',
+                'LOTNUM':'中签号',
+                'COMPROFILE':'公司简介',
+                'BUSINESS':'经营范围',
+            }            
+            try:
+                query = db_session.query(EmStockIpoInfo)
+                df = pd.read_sql(query.statement, query.session.bind).drop(columns=['_update_time']).rename(columns=col_dic)
+                df['股票代码不带市场'] = df.股票代码.map(lambda x : x.split('.')[0])
+                df['申购代码'] = df.申购代码带市场.map(lambda x : x.split('.')[0])
+                df['申购资金上限'] = df['发行价'] * df['申购数量上限']
+                return df
+
+            except Exception as e:
+                print(f'Failed to get_em_stock_ipo_info <err_msg> {e} from {EmStockIpoInfo.__tablename__}')
+                return pd.DataFrame([])
+
+    def get_em_conv_bond_ipo_info(self):
+        with RawDatabaseConnector().managed_session() as db_session:
+            col_dic = {
+                'CODES':'转债代码',
+                'CBCODE' : '转债代码无市场',
+                'CBNAME' : '转债简称',
+                'CBSTOCKCODE':'正股代码',
+                'CBSTOCKNAME':'正股简称',
+                'CBISSUEAMT':'发行规模',
+                'IPOANNCDATE':'发行公告日',
+                'CBIPOTYPE':'发行方式',
+                'CBPURCODEONL':'申购代码',
+                'ISSRATE':'发行时债项评级',
+                'CBTERM':'发行期限',
+                'CBISSUEPRICE':'发行价格',
+                'ISSUEONLEDATE':'发行截止日期',
+                'CBCONVPRICE':'转股价',
+                'CBDATEONL':'申购日期',
+                'CBLISTDATE':'上市日期',
+                'CBRESULTDATE':'中签公布',
+                'CBSUCRATEONL':'中签率',
+                'QUANTLIMITINTRO':'申购数量限制说明',
+                'CBMATURITYDATE':'到期日',
+                'CBREDEMPRICETM':'到期赎回价格',
+                'CBRATIONCODE':'配售代码',
+                'CBSUCCESS':'中签号',
+                'CBPUTBACKPRICEEXPLAIN':'回售价格说明',
+                'CBREDEMMEMO':'赎回价格说明',
+            }
+            try:
+                query = db_session.query(
+                    EmConvBondIpoInfo,
+                ).filter(
+                    EmConvBondIpoInfo.CBIPOTYPE == '公募',
+                )
+                df = pd.read_sql(query.statement, query.session.bind).drop(columns=['_update_time']).rename(columns=col_dic)
+                df.loc[:,'stock_id'] = df.正股代码 + '.' +df.转债代码.map(lambda x: x.split('.')[1])
+                stock_price = self.get_em_stock_price_recent(df.stock_id.tolist())
+                df = pd.merge(df, stock_price[['close','stock_id']], on='stock_id').drop(columns=['stock_id']).rename(columns={'close':'正股价'})
+                df['溢价率'] = df.转股价 / df.正股价 - 1
+                df['转股价值'] = df.发行价格 / df.转股价 * df.正股价
+                df['回售价'] = None if df.回售价格说明 is None else df.发行价格
+                df['赎回价'] = None if df.赎回价格说明 is None else df.发行价格
+                df['申购数量上限'] = df.申购数量限制说明.map(lambda x: int(x.split('网上申购数量上限：')[1].split('手')[0])*10)
+                df['申购代码带市场'] = df.申购代码 + '.' +df.转债代码.map(lambda x: x.split('.')[1])
+                df = df.drop(columns=['回售价格说明','赎回价格说明'])
+                return df
+
+            except Exception as e:
+                print(f'Failed to get_em_conv_bond_ipo_info <err_msg> {e} from {EmConvBondIpoInfo.__tablename__}')
+                return pd.DataFrame([])
+
+
+    def get_em_stock_concept_info(self):
+        with RawDatabaseConnector().managed_session() as db_session:
+            try:
+                query = db_session.query(EmStockConceptInfo)
+                df = pd.read_sql(query.statement, query.session.bind).drop(columns=['_update_time'])
+                return df
+
+            except Exception as e:
+                print(f'Failed to get_em_stock_concept_info <err_msg> {e} from {EmStockConceptInfo.__tablename__}')
+                return pd.DataFrame([])
\ No newline at end of file
