@@ -1,7 +1,9 @@
 
 import datetime
 from typing import List
+import traceback
 import pandas as pd
+
 from .fund_indicator_processor import FundIndicatorProcessor
 # from .derived_index_val import IndexValProcess
 from .derived_index_val_long_term import IndexValProcessLongTerm
@@ -70,57 +72,62 @@ class DerivedDataProcessor:
 
     def process_all(self, start_date, end_date):
         failed_tasks = []
-        failed_tasks.extend(self.fund_indicator_processor.process(start_date, end_date))
-        # failed_tasks.extend(self.index_val_processor.process(start_date, end_date))
-        failed_tasks.extend(self.index_val_processor_long_term.process(start_date, end_date))
-        failed_tasks.extend(self.index_indicator.process(end_date))
-        failed_tasks.extend(self._manager_processor.process(end_date))
-        failed_tasks.extend(self.fund_aip.process(start_date, end_date))
-        failed_tasks.extend(self._barra_cne5_factor_processor.process(start_date, end_date))
-        failed_tasks.extend(self._style_regression_processor.process(start_date, end_date))
-        failed_tasks.extend(self._style_box_processor.process(start_date, end_date))
-        failed_tasks.extend(self.mng_fund_rank.process(end_date))
-        failed_tasks.extend(self._fund_alpha_processor.process(start_date, end_date))
-        failed_tasks.extend(self.top_manager_funds_processor.process(start_date, end_date))
-        for sap in self.style_analysis_processors:
-            failed_tasks.extend(sap.process(start_date, end_date))
-        failed_tasks.extend(self._qieman_portfolio_processor.process(end_date))
-        failed_tasks.extend(self._danjuan_portfolio_processor.process(end_date))
-        failed_tasks.extend(self._em_portfolio_processor.process(end_date))
-        failed_tasks.extend(self._gf_sec_portfolio_processor.process(end_date))
-        failed_tasks.extend(self._manually_crawled_portfolio_processor.process(end_date))
+        try:
+            failed_tasks.extend(self.fund_indicator_processor.process(start_date, end_date))
+            # failed_tasks.extend(self.index_val_processor.process(start_date, end_date))
+            failed_tasks.extend(self.index_val_processor_long_term.process(start_date, end_date))
+            failed_tasks.extend(self.index_indicator.process(end_date))
+            failed_tasks.extend(self._manager_processor.process(end_date))
+            failed_tasks.extend(self.fund_aip.process(start_date, end_date))
+            failed_tasks.extend(self._barra_cne5_factor_processor.process(start_date, end_date))
+            failed_tasks.extend(self._style_regression_processor.process(start_date, end_date))
+            failed_tasks.extend(self._style_box_processor.process(start_date, end_date))
+            failed_tasks.extend(self.mng_fund_rank.process(end_date))
+            failed_tasks.extend(self._fund_alpha_processor.process(start_date, end_date))
+            failed_tasks.extend(self.top_manager_funds_processor.process(start_date, end_date))
+            for sap in self.style_analysis_processors:
+                failed_tasks.extend(sap.process(start_date, end_date))
+            failed_tasks.extend(self._qieman_portfolio_processor.process(end_date))
+            failed_tasks.extend(self._danjuan_portfolio_processor.process(end_date))
+            failed_tasks.extend(self._em_portfolio_processor.process(end_date))
+            failed_tasks.extend(self._gf_sec_portfolio_processor.process(end_date))
+            failed_tasks.extend(self._manually_crawled_portfolio_processor.process(end_date))
 
-        # 获取下一个交易日
-        api = BasicDataApi()
-        trading_day_df = api.get_trading_day_list(start_date=end_date)
-        if trading_day_df.shape[0] <= 1:
-            print(f'get trading days start with {end_date} failed')
-            failed_tasks.append('get_trading_day for weekly/monthly indicator')
-        else:
-            next_trading_day = trading_day_df.iloc[1, :].datetime
-            print(f'got next trading day {next_trading_day}')
-            end_date_dt = pd.to_datetime(end_date, infer_datetime_format=True).date()
-            next_trading_dt = pd.to_datetime(next_trading_day, infer_datetime_format=True).date()
-            if end_date_dt.weekday() < next_trading_dt.weekday() and next_trading_dt < end_date_dt + datetime.timedelta(weeks=1):
-                # 表明本周后边还有交易日，今天不需要更新
-                print(f'weekly indicator only update on the last day of week, not today {end_date_dt}')
+            # 获取下一个交易日
+            api = BasicDataApi()
+            trading_day_df = api.get_trading_day_list(start_date=end_date)
+            if trading_day_df.shape[0] <= 1:
+                print(f'get trading days start with {end_date} failed')
+                failed_tasks.append('get_trading_day for weekly/monthly indicator')
             else:
-                failed_tasks.extend(self.fund_indicator_processor_weekly.process(start_date, end_date, end_date_dt))
-                # 分别用2年和5年的数据算一下
-                failed_tasks.extend(self.fund_indicator_processor_group_1Y.process(start_date, end_date, end_date_dt))
-                failed_tasks.extend(self.fund_indicator_processor_group_5Y.process(start_date, end_date, end_date_dt))
-                # failed_tasks.extend(self._derived_fund_score_extended.process(start_date, end_date, end_date_dt))
-                failed_tasks.extend(self._derived_fund_score_group_v1_1Y.process(start_date, end_date, end_date_dt))
-                failed_tasks.extend(self._derived_fund_score_group_v1_5Y.process(start_date, end_date, end_date_dt))
-                failed_tasks.extend(self._derived_fund_score_group_1Y.process(start_date, end_date, end_date_dt))
-                failed_tasks.extend(self._derived_fund_score_group_5Y.process(start_date, end_date, end_date_dt))
-                failed_tasks.extend(self._fund_industry_exposure.process(start_date, end_date, end_date_dt))
+                next_trading_day = trading_day_df.iloc[1, :].datetime
+                print(f'got next trading day {next_trading_day}')
+                end_date_dt = pd.to_datetime(end_date, infer_datetime_format=True).date()
+                next_trading_dt = pd.to_datetime(next_trading_day, infer_datetime_format=True).date()
+                if end_date_dt.weekday() < next_trading_dt.weekday() and next_trading_dt < end_date_dt + datetime.timedelta(weeks=1):
+                    # 表明本周后边还有交易日，今天不需要更新
+                    print(f'weekly indicator only update on the last day of week, not today {end_date_dt}')
+                else:
+                    failed_tasks.extend(self.fund_indicator_processor_weekly.process(start_date, end_date, end_date_dt))
+                    # 分别用2年和5年的数据算一下
+                    failed_tasks.extend(self.fund_indicator_processor_group_1Y.process(start_date, end_date, end_date_dt))
+                    failed_tasks.extend(self.fund_indicator_processor_group_5Y.process(start_date, end_date, end_date_dt))
+                    # failed_tasks.extend(self._derived_fund_score_extended.process(start_date, end_date, end_date_dt))
+                    failed_tasks.extend(self._derived_fund_score_group_v1_1Y.process(start_date, end_date, end_date_dt))
+                    failed_tasks.extend(self._derived_fund_score_group_v1_5Y.process(start_date, end_date, end_date_dt))
+                    failed_tasks.extend(self._derived_fund_score_group_1Y.process(start_date, end_date, end_date_dt))
+                    failed_tasks.extend(self._derived_fund_score_group_5Y.process(start_date, end_date, end_date_dt))
+                    failed_tasks.extend(self._fund_industry_exposure.process(start_date, end_date, end_date_dt))
 
-            if end_date_dt.year == next_trading_dt.year and end_date_dt.month == next_trading_dt.month:
-                # 表明本月后边还有交易日，今天不需要更新
-                print(f'monthly indicator only update on the last day of month, not today {end_date_dt}')
-            else:
-                failed_tasks.extend(self.fund_indicator_processor_monthly.process(start_date, end_date, end_date_dt))
+                if end_date_dt.year == next_trading_dt.year and end_date_dt.month == next_trading_dt.month:
+                    # 表明本月后边还有交易日，今天不需要更新
+                    print(f'monthly indicator only update on the last day of month, not today {end_date_dt}')
+                else:
+                    failed_tasks.extend(self.fund_indicator_processor_monthly.process(start_date, end_date, end_date_dt))
+        except Exception as e:
+            print(e)
+            traceback.print_exc()
+            failed_tasks.append('unknown in derived_data_processor')
         return failed_tasks
 
     def get_updated_count(self):
