@@ -154,6 +154,7 @@ class FundIndicatorProcessorGroup:
         # monthly ret
         _df = self.fund_nav.tail(20)
         self.monthly_ret = _df.iloc[-1] / _df.iloc[0]
+        self.fund_info = self.fund_info.set_index('fund_id')
 
     def get_benchmark_return(self) -> pd.DataFrame:
         benchmark_list: Dict[str, float] = {}
@@ -394,7 +395,7 @@ class FundIndicatorProcessorGroup:
         self.result_df.loc[:,'scale'] = self.fund_size.loc[self.end_date]
         self.result_df.loc[:,'monthly_ret'] = self.monthly_ret
         self.result_df.loc[:,'total_ret'] = np.exp(self.fund_ret.sum())
-
+        self.result_df.loc[:,'mdd~history_daily'] = 1 - (self.fund_nav / self.fund_nav.cummax()).min()
         self.result_df = self.result_df.reset_index()
 
         self.fund_info.loc[:,'trade_days'] = [i.days for i in (self.end_date - self.fund_info.start_date)]
@@ -403,6 +404,7 @@ class FundIndicatorProcessorGroup:
         self.result_df = self.result_df.join(self.fund_info[['wind_class_2','fund_type','desc_name']])
         self.result_df = self.result_df.replace(np.Inf,np.nan).replace(-np.Inf,np.nan)
         self.result_df= self.result_df.join(self.fund_info[['trade_days']])
+        self.indicator = self.result_df.copy()
         _t11 = time.time()
         print(f'total cost time {_t11 - _t00}')
 
@@ -414,7 +416,7 @@ class FundIndicatorProcessorGroup:
             if fund_type == 'stock':
                 #df.loc[:,'ret_ability'] = score_rescale(0.6 * normalize(df['alpha~history_m']) + 0.4 * ret)
                 df.loc[:,'ret_ability'] = score_rescale( 0.4 * score_rescale(df['annual_ret~history_m']) + 0.6 * score_rescale(df['total_ret']))
-                df.loc[:,'risk_ability'] = score_rescale(0.3 * score_rescale(-df['mdd~history_m']) + 0.4 * score_rescale(-df['annual_vol~history_m']) + 0.3 * score_rescale(-df['downside_std~history_m']))
+                df.loc[:,'risk_ability'] = score_rescale(0.3 * score_rescale(-df['mdd~history_daily']) + 0.4 * score_rescale(-df['annual_vol~history_m']) + 0.3 * score_rescale(-df['downside_std~history_m']))
                 df.loc[:,'stable_ability'] = score_rescale(0.4 * score_rescale(df['trade_days']) + 0.4 * score_rescale(df['continue_regress_v~history_m']) + 0.2 * score_rescale(df['scale']))
                 df.loc[:,'select_time'] =  score_rescale(normalize(df['stock_cl_beta~history_w']))
                 df.loc[:,'select_stock'] = score_rescale(normalize(df['stock_cl_alpha~history_w']))
@@ -422,22 +424,22 @@ class FundIndicatorProcessorGroup:
             
             elif fund_type == 'bond':
                 df.loc[:,'ret_ability'] = score_rescale( 0.8 * score_rescale(df['annual_ret~history_m']) + 0.2 * score_rescale(df['total_ret']))
-                df.loc[:,'risk_ability'] = score_rescale(0.3 * score_rescale(-df['mdd~history_m']) + 0.4 * score_rescale(-df['annual_vol~history_m']) + 0.3 * score_rescale(-df['downside_std~history_m']))
+                df.loc[:,'risk_ability'] = score_rescale(0.3 * score_rescale(-df['mdd~history_daily']) + 0.4 * score_rescale(-df['annual_vol~history_m']) + 0.3 * score_rescale(-df['downside_std~history_m']))
                 df.loc[:,'stable_ability'] = score_rescale(0.4 * score_rescale(df['trade_days']) + 0.4 * score_rescale(df['continue_regress_v~history_m']) + 0.2 * score_rescale(df['scale']))
                 df.loc[:,'select_time'] =  score_rescale(normalize(df['stock_cl_beta~history_w']))
                 df.loc[:,'select_stock'] = score_rescale(normalize(df['stock_cl_alpha~history_w']))
                 df.loc[:,'total_score'] = score_rescale(df.loc[:,'ret_ability'] + df.loc[:,'risk_ability'] + df.loc[:,'stable_ability'] + df.loc[:,'select_time'] + df.loc[:,'select_stock'] )
             
             elif fund_type == 'index':
-                df.loc[:,'alpha_ability'] = score_rescale( 0.4 * score_rescale(df['annual_ret~history_m']) + 0.6 * score_rescale(df['total_ret']))
+                df.loc[:,'ret_ability'] = score_rescale( 0.4 * score_rescale(df['annual_ret~history_m']) + 0.6 * score_rescale(df['total_ret']))
                 #df.loc[:,'track_ability'] = score_rescale(-normalize(df['track_err~history_m']))
-                df.loc[:,'risk_ability'] = score_rescale(0.3 * score_rescale(-df['mdd~history_m']) + 0.4 * score_rescale(-df['annual_vol~history_m']) + 0.3 * score_rescale(-df['downside_std~history_m']))
+                df.loc[:,'risk_ability'] = score_rescale(0.3 * score_rescale(-df['mdd~history_daily']) + 0.4 * score_rescale(-df['annual_vol~history_m']) + 0.3 * score_rescale(-df['downside_std~history_m']))
                 df.loc[:,'stable_ability'] = score_rescale(0.4 * score_rescale(df['trade_days']) + 0.4 * score_rescale(df['continue_regress_v~history_m']) + 0.2 * score_rescale(df['scale']))
-                df.loc[:,'total_score'] = score_rescale(df.loc[:,'alpha_ability'] + df.loc[:,'risk_ability'] + df.loc[:,'stable_ability'] )
+                df.loc[:,'total_score'] = score_rescale(df.loc[:,'ret_ability'] + df.loc[:,'risk_ability'] + df.loc[:,'stable_ability'] )
             
             elif fund_type == 'QDII':
                 df.loc[:,'ret_ability'] = score_rescale( 0.4 * score_rescale(df['annual_ret~history_m']) + 0.6 * score_rescale(df['total_ret']))
-                df.loc[:,'risk_ability'] = score_rescale(0.3 * score_rescale(-df['mdd~history_m']) + 0.4 * score_rescale(-df['annual_vol~history_m']) + 0.3 * score_rescale(-df['downside_std~history_m']))
+                df.loc[:,'risk_ability'] = score_rescale(0.3 * score_rescale(-df['mdd~history_daily']) + 0.4 * score_rescale(-df['annual_vol~history_m']) + 0.3 * score_rescale(-df['downside_std~history_m']))
                 df.loc[:,'stable_ability'] = score_rescale(-normalize(df['annual_vol~history_m']))
                 df.loc[:,'select_time'] = np.nan
                 df.loc[:,'select_stock'] = np.nan
@@ -472,7 +474,7 @@ class FundIndicatorProcessorGroup:
         s3_uri = f'{_s3_bucket_uri}/{name}.parquet'
         score = pd.read_parquet(s3_uri)
         
-        mng_info = DerivedDataApi().derived_data(func_name='get_fund_manager_info')
+        mng_info = DerivedDataApi().get_fund_manager_info().set_index('mng_id')
         mng_dic = mng_info[mng_info.end_date == datetime.date(2040,1,1)]['fund_id']
 
         # 找基金对应基金经理分数
@@ -484,13 +486,13 @@ class FundIndicatorProcessorGroup:
             _score = _score.set_index('mng_id').join(mng_dic)
             _score = _score.reset_index().set_index('fund_id').rename(columns={'total_score':'mng_score'})[['mng_score']]
             _score = _score.reset_index().groupby('fund_id').max()
-            _fund_indicator_part = _fund_indicator_part.drop(columns='mng_score').join(_score['mng_score'])
+            _fund_indicator_part = _fund_indicator_part.drop(columns='mng_score',errors='ignore').join(_score['mng_score'])
             res.append(_fund_indicator_part)
         fund_indicator = pd.concat(res,axis=0)
         dic = {
             'stock':['ret_ability','risk_ability','stable_ability','select_time','select_stock','mng_score'],
             'bond':['ret_ability','risk_ability','stable_ability','select_time','select_stock','mng_score'],
-            'index':['alpha_ability','risk_ability','stable_ability','mng_score'],
+            'index':['ret_ability','risk_ability','stable_ability','mng_score'],
             'QDII':['ret_ability','risk_ability','stable_ability','mng_score'],
             'mmf':['ret_ability','risk_ability','mng_score']
         }
