@@ -470,6 +470,8 @@ class ManagerProcessor:
         mng_result.update({'trading_days': (self.end_date - this_manager_whole_info.start.min()).days})  
         mng_result.update({'scale': self.fund_size.loc[self.end_date, still_work_fund_ids].sum()})
         mng_result.update({'total_ret': self.fund_type_df[mng_id].values[-1]})
+        _mng_index = self.fund_type_df[mng_id]
+        mng_result.update({'mdd~history_daily': 1 - (_mng_index / _mng_index.cummax()).min()})
         _t1 = time.time()
         print(f'{mng_id} {idx} / {len(self.type_manager_list)} cost time {_t1 - _t0}')
         return mng_result
@@ -504,7 +506,7 @@ class ManagerProcessor:
             df = self.manager_indicator[self.manager_indicator['fund_type'] == fund_type].copy()
             if fund_type == 'stock':
                 df.loc[:,'ret_ability'] = score_rescale( 0.4 * score_rescale(df['annual_ret~history_m']) + 0.6 * score_rescale(df['total_ret']))
-                df.loc[:,'risk_ability'] = score_rescale(0.3 * score_rescale(-df['mdd~history_m']) + 0.4 * score_rescale(-df['annual_vol~history_m']) + 0.3 * score_rescale(-df['downside_std~history_m']))
+                df.loc[:,'risk_ability'] = score_rescale(0.3 * score_rescale(-df['mdd~history_daily']) + 0.4 * score_rescale(-df['annual_vol~history_m']) + 0.3 * score_rescale(-df['downside_std~history_m']))
                 df.loc[:,'select_time'] =  score_rescale(normalize(df['stock_cl_beta~history_w']))
                 df.loc[:,'select_stock'] = score_rescale(normalize(df['stock_cl_alpha~history_w']) )
                 df.loc[:,'experience'] = score_rescale( 0.8 *  score_rescale(df['fund_type_trading_days']) + 0.2 * score_rescale(df['scale']))
@@ -512,21 +514,21 @@ class ManagerProcessor:
             
             elif fund_type == 'bond':
                 df.loc[:,'ret_ability'] = score_rescale( 0.8 * score_rescale(df['annual_ret~history_m']) + 0.2 * score_rescale(df['total_ret']))
-                df.loc[:,'risk_ability'] = score_rescale(0.1 * score_rescale(-df['mdd~history_m']) + 0.4 * score_rescale(-df['annual_vol~history_m']) + 0.5 * score_rescale(-df['downside_std~history_m']))
+                df.loc[:,'risk_ability'] = score_rescale(0.1 * score_rescale(-df['mdd~history_daily']) + 0.4 * score_rescale(-df['annual_vol~history_m']) + 0.5 * score_rescale(-df['downside_std~history_m']))
                 df.loc[:,'select_time'] =  score_rescale(normalize(df['stock_cl_beta~history_w']))
                 df.loc[:,'select_stock'] = score_rescale(normalize(df['stock_cl_alpha~history_w']))
                 df.loc[:,'experience'] = score_rescale( 0.8 *  score_rescale(df['fund_type_trading_days']) + 0.2 * score_rescale(df['scale']))
                 df.loc[:,'total_score'] = score_rescale(1.2 * df.loc[:,'ret_ability'] +  df.loc[:,'risk_ability'] + df.loc[:,'select_time'] + df.loc[:,'select_stock'] + 1.5 * df.loc[:,'experience'])
             
             elif fund_type == 'index':
-                df.loc[:,'alpha_ability'] = score_rescale( 0.4 * score_rescale(df['annual_ret~history_m']) + 0.6 * score_rescale(df['total_ret']))
-                df.loc[:,'risk_ability'] = score_rescale(0.3 * score_rescale(-df['mdd~history_m']) + 0.4 * score_rescale(-df['annual_vol~history_m']) + 0.3 * score_rescale(-df['downside_std~history_m']))
+                df.loc[:,'ret_ability'] = score_rescale( 0.4 * score_rescale(df['annual_ret~history_m']) + 0.6 * score_rescale(df['total_ret']))
+                df.loc[:,'risk_ability'] = score_rescale(0.3 * score_rescale(-df['mdd~history_daily']) + 0.4 * score_rescale(-df['annual_vol~history_m']) + 0.3 * score_rescale(-df['downside_std~history_m']))
                 df.loc[:,'experience'] = score_rescale( 0.4 *  score_rescale(df['fund_type_trading_days']) + 0.6 * score_rescale(df['scale']))
-                df.loc[:,'total_score'] = score_rescale(df.loc[:,'alpha_ability'] + df.loc[:,'risk_ability'] + 2 * df.loc[:,'experience'] )
+                df.loc[:,'total_score'] = score_rescale(df.loc[:,'ret_ability'] + df.loc[:,'risk_ability'] + 2 * df.loc[:,'experience'] )
             
             elif fund_type == 'QDII':
                 df.loc[:,'ret_ability'] = score_rescale( 0.4 * score_rescale(df['annual_ret~history_m']) + 0.6 * score_rescale(df['total_ret']))
-                df.loc[:,'risk_ability'] = score_rescale(0.3 * score_rescale(-df['mdd~history_m']) + 0.4 * score_rescale(-df['annual_vol~history_m']) + 0.3 * score_rescale(-df['downside_std~history_m']))
+                df.loc[:,'risk_ability'] = score_rescale(0.3 * score_rescale(-df['mdd~history_daily']) + 0.4 * score_rescale(-df['annual_vol~history_m']) + 0.3 * score_rescale(-df['downside_std~history_m']))
                 df.loc[:,'stable_ability'] = score_rescale(-normalize(df['annual_vol~history_m']))
                 df.loc[:,'select_time'] = np.nan
                 df.loc[:,'select_stock'] = np.nan
