@@ -7,8 +7,8 @@ from .web_raw_data_downloader import WebRawDataDownloader
 from .raw_data_helper import RawDataHelper
 
 
-class RawDataDownloader(object):
-    def __init__(self, rq_license):
+class RawDataDownloader:
+    def __init__(self, rq_license=None):
         self._data_helper = RawDataHelper()
         # self.rq_downloader = RqRawDataDownloader(rq_license, self._data_helper)
         self.web_downloader = WebRawDataDownloader(self._data_helper)
