@@ -2,12 +2,13 @@ import pandas as pd
 import traceback
 import json
 from sqlalchemy import func
+from .compute_fund_recommendation_collection import FundRecommendationCollectionProcessor
 from ...wrapper.mysql import (RawDatabaseConnector, BasicDatabaseConnector, DerivedDatabaseConnector, 
     ViewDatabaseConnector)
 from ...view.view_models import FundDailyCollection
 from ...view.basic_models import FundNav, FundInfo, FundRate, FundSize, FundRet, FundBenchmark, IndexInfo, \
     FundStatusLatest
-from ...view.derived_models import FundAlpha, FundIndicator, FundScoreNew, FundManagerInfo
+from ...view.derived_models import FundAlpha, FundIndicator, FundScoreNew, FundManagerInfo, StyleBox
 from ....constant import ExchangeStatus
 from .__init__ import fund_s3_uri
 
@@ -23,6 +24,7 @@ class FundDailyCollectionProcessor(object):
 
     def __init__(self):
         self.fund_type_dic = {}
+        self.fund_recommend = FundRecommendationCollectionProcessor()
         for k, v in self.FUND_CLASSIFIER.items():
             for v_i in v:
                 self.fund_type_dic[v_i] = k
@@ -37,13 +39,28 @@ class FundDailyCollectionProcessor(object):
                     FundInfo.wind_class_2,
                     FundInfo.start_date,
                     FundInfo.end_date,
-                    # FundInfo.manager_id,
+                    #FundInfo.desc_name,
                     FundInfo.company_id,
                     FundInfo.benchmark,
                     FundInfo.desc_name,
                     FundInfo.track_index,
                     FundInfo.manage_fee,
+                    FundInfo.start_date,
+                    FundInfo.end_date,
+                    FundInfo.risk_level,
+                    FundInfo.company_id,
+                    FundInfo.full_name,
+                    FundInfo.currency,
+                    FundInfo.manage_fee,
                     FundInfo.trustee_fee,
+                    FundInfo.purchase_fee,
+                    FundInfo.redeem_fee,
+                    FundInfo.benchmark_1,
+                    FundInfo.benchmark_2,
+                    FundInfo.subscr_fee_detail,
+                    FundInfo.purchase_fee_detail,
+                    FundInfo.redeem_fee_detail,
+                    FundInfo.service_fee,
                 )
                 funds = pd.read_sql(query.statement, query.session.bind)
                 return funds.set_index('fund_id')
@@ -134,7 +151,7 @@ class FundDailyCollectionProcessor(object):
                     FundRet.annual_ret,
                     # FundRet.annualized_risk,
                     FundRet.vol,
-                    FundRet.avg_size,
+                    #FundRet.avg_size,
                     FundRet.info_ratio,
                     FundRet.w1_ret,
                     FundRet.m1_ret,
@@ -161,7 +178,7 @@ class FundDailyCollectionProcessor(object):
                     'to_date_ret': 'to_date_return',
                     'sharpe_ratio': 'sharp_ratio',
                     'mdd': 'max_drop_down',
-                    'avg_size': 'average_size',
+                    #'avg_size': 'average_size',
                 })
                 return indicator
 
@@ -222,6 +239,7 @@ class FundDailyCollectionProcessor(object):
                     FundManagerInfo.fund_id,
                     FundManagerInfo.mng_id,
                     FundManagerInfo.mng_name,
+                    FundManagerInfo.profit,
                 ).filter(
                     FundManagerInfo.end_date == '2040-01-01',
                 )
@@ -231,12 +249,30 @@ class FundDailyCollectionProcessor(object):
                 df = df.rename(columns={
                     'mng_name': 'fund_manager',
                     'mng_id': 'fund_manager_id',
+                    'profit': 'manager_profit',
                 })
                 df = df.set_index('fund_id')
                 return df
             except Exception as e:
                 print('Failed fill get data <err_msg> {}'.format(e))
 
+    def get_fund_manager_info_raw_df(self):
+        with DerivedDatabaseConnector().managed_session() as mn_session:
+            try:
+                query = mn_session.query(
+                    FundManagerInfo.fund_id,
+                    FundManagerInfo.mng_id,
+                    FundManagerInfo.mng_name,
+                    FundManagerInfo.profit
+                ).filter(
+                    FundManagerInfo.end_date == '2040-01-01',
+                )
+                df = pd.read_sql(query.statement, query.session.bind)
+                df = df
+                return df
+            except Exception as e:
+                print('Failed fill get data <err_msg> {}'.format(e))
+
     def get_exchange_status_df(self):
         with BasicDatabaseConnector().managed_session() as mn_session:
             try:
@@ -281,6 +317,42 @@ class FundDailyCollectionProcessor(object):
             except Exception as e:
                 print('Failed fill get data <err_msg> {}'.format(e))
 
+    def get_style_df(self):
+        with DerivedDatabaseConnector().managed_session() as mn_session:
+            try:
+                latest_time = mn_session.query(StyleBox).order_by(StyleBox.datetime.desc()).limit(1).one_or_none()
+                latest_time = latest_time.datetime
+                query = mn_session.query(
+                    StyleBox
+                ).filter(StyleBox.datetime==latest_time)
+                df = pd.read_sql(query.statement, query.session.bind).drop(columns=['_update_time'])
+                return df
+            except Exception as e:
+                print('Failed fill get data <err_msg> {}'.format(e))
+
+    def get_style_box_detail(self):
+        def fund_style(x):
+            if pd.isna(x):
+                return None
+            if x < 125:
+                return '价值型'
+            if x <= 175:
+                return '平衡型'
+            return '成长型'
+
+        def fund_size(x):
+            if pd.isna(x):
+                return None
+            if x < 100:
+                return '小盘'
+            if x <= 200:
+                return '中盘'
+            return '大盘'
+        df = self.get_style_df()
+        df['fund_size_type'] = df['y'].apply(fund_size)
+        df['fund_style_type'] = df['x'].apply(fund_style)
+        return df[['fund_size_type','fund_style_type','fund_id']].set_index('fund_id')
+
     def append_data(self, table_name, data_append_directly_data_df):
         if not data_append_directly_data_df.empty:
             with ViewDatabaseConnector().managed_session() as mn_session:
@@ -335,9 +407,25 @@ class FundDailyCollectionProcessor(object):
             x['benchmark_name'] = None
         return x
 
+    def parse_benchmark_1(self, fund_info):
+        benchmark_split_chname = []
+        multi_sign_list = ['*','×']
+        for r in fund_info.itertuples():
+            b = r.benchmark
+            if b is None or b == '':
+                result = None
+            else:
+                for mul_sign in multi_sign_list:
+                    if mul_sign in b:
+                        result = b.split(mul_sign)[0].replace('收益率','')
+            benchmark_split_chname.append(result)     
+        fund_info.loc[:, 'first_benchmark_name'] = benchmark_split_chname
+        return fund_info
+
     def compute_daily_collection(self):
         try:
             funds = self.get_fund_df()
+            funds = self.parse_benchmark_1(funds)
             funds = funds.reset_index()
             funds = funds.drop_duplicates(subset=['fund_id'], keep='last')
             funds = funds.set_index('fund_id')
@@ -383,13 +471,12 @@ class FundDailyCollectionProcessor(object):
             new_score = fund_indicator_score.rename(columns=score_name_dic)[list(score_name_dic.values())]      
             print(new_score)
             print('-' * 100)
-
             indicator_name_dic = {  'alpha~history_m':'alpha',
                                     'beta~history_m':'beta',
                                     'track_err~history_m':'tag_track_err',
                                     'info_ratio~history_m':'info_ratio',
                                     'treynor~history_m':'treynor',
-                                    'mdd~history_m':'mdd',
+                                    'mdd~history_daily':'mdd',
                                     'downside_std~history_m':'down_risk',
                                     'total_ret':'ret_over_period',
                                     'annual_ret~history_m':'annual_avg_daily_ret',
@@ -397,7 +484,12 @@ class FundDailyCollectionProcessor(object):
                                     'annual_ret~history_m':'annual_ret',
                                     'stock_cl_beta~history_w':'time_ret',
                                     'var~history_m':'var',
-                                    'sharpe~history_m':'sharpe'
+                                    'sharpe~history_m':'sharpe',
+                                    'downside_std~history_m':'downside_std',
+                                    'continue_regress_v~history_m':'continue_regress_v',
+                                    'stock_cl_beta~history_w':'stock_cl_beta',
+                                    'stock_cl_alpha~history_w':'stock_cl_alpha',
+                                    'prn_hold':'prn_hold',
                                 }
             tag_indicator = fund_indicator_score.rename(columns=indicator_name_dic)[list(indicator_name_dic.values())] 
             tag_indicator = tag_indicator.join(pd.DataFrame(funds.manage_fee + funds.trustee_fee,columns=['fee_rate']))
@@ -406,16 +498,31 @@ class FundDailyCollectionProcessor(object):
             print(tag_indicator)
             print('-' * 100)
             
+
+            print('处理基金经理')
+            fund_manager = self.get_fund_manager_info_df()
+            print(fund_manager)
+            
+            print('处理推荐信息和概念')
+            fund_recommend_list = ['sector_list','sector_name','index_list','index_name','mng_id','is_abs_ret_fund','is_conv_bond_fund','fund_id']
+            fund_recommend_list = fund_recommend_list + ['is_ipo_fund','fund_type']
+            fund_recommend_extend = self.fund_recommend.calc_whole_data()
+            fund_recommend_extend = fund_recommend_extend[fund_recommend_list]
+
+            _manager_info = self.get_fund_manager_info_raw_df()
+            _col = {
+                'mng_name':'top_mng_name',
+                'profit':'top_manager_profit',
+                'mng_id':'top_mng_id'
+            }   
+            fund_recommend_extend = fund_recommend_extend.set_index(['fund_id','mng_id']).join(_manager_info.set_index(['fund_id','mng_id'])).reset_index().rename(columns=_col).set_index('fund_id')
+
             funds = funds.drop(columns=['manage_fee','trustee_fee'])
             exchange_status = self.get_exchange_status_df().set_index('fund_id')
             print(exchange_status)
             print('-' * 100)
 
-            print('处理基金经理')
-            fund_manager = self.get_fund_manager_info_df()
-            print(fund_manager)
-
-
+            
             print('处理机构评级')
             rating = self.get_institution_rating_df()
             rating = rating.drop_duplicates(subset=['fund_id'], keep='last')
@@ -423,8 +530,11 @@ class FundDailyCollectionProcessor(object):
             print(rating)
             print('-' * 100)
 
+            print('处理基金风格')
+            style_df = self.get_style_box_detail()
+
             print('处理净值')
-            df = pd.concat([funds, bench, nav, alpha, size, rating, score, new_score, tag_indicator, exchange_status, fund_manager], axis=1, sort=False)
+            df = pd.concat([funds, bench, nav, alpha, size, rating, score, new_score, tag_indicator, exchange_status, fund_recommend_extend, fund_manager, style_df], axis=1, sort=False)
             df.index.name = 'fund_id'
             print('_'*100)
             print(df)
