@@ -5,6 +5,41 @@ import datetime
 from typing import Tuple
 
 
+@dataclasses.dataclass
+class StockInfoDataTables:
+
+    values: pd.DataFrame = None             # 天度ratios
+    finance: pd.DataFrame = None            # 财报ratios
+    dividend: pd.DataFrame = None           # 分红
+    equity: pd.DataFrame = None             # 股本
+    prices: pd.DataFrame = None             # 价格
+    real_dates: pd.DataFrame = None         # 财报发布日期
+
+    balance: pd.DataFrame = None
+
+    income: pd.DataFrame = None
+    income_q: pd.DataFrame = None
+    income_ttm: pd.DataFrame = None
+
+    cash_flow: pd.DataFrame = None
+    cash_flow_q: pd.DataFrame = None
+    cash_flow_ttm: pd.DataFrame = None
+
+    factor_dict: dict = None
+
+    def __post_init__(self):
+        self.factor_dict = {}
+
+
+@dataclasses.dataclass
+class StocksDataTables:
+    stocks: dict = None                          # {'stock_id': StockInfoDataTables()}
+    daily_collection: pd.DataFrame = None           # 最新截面数据
+
+    def __post_init__(self):
+        self.stocks = {}
+
+
 @dataclasses.dataclass
 class FundDataTables:
     # raw
@@ -46,11 +81,22 @@ class FundDataTables:
     mng_best_fund: dict = None
     # score helps
     index_fund_indicator_pack: pd.DataFrame = None  # pivot_table
-    
+    stock_ipo_data: dict = None
+    conv_bond_ipo_data: dict = None
+    stock_ipo_data_detail: dict = None
+    conv_bond_ipo_data_detail: dict = None
+    stock_ipo_info: dict = None
+    conv_bond_ipo_info: dict = None
 
     def __post_init__(self):
         self.fund_list = self.fund_list or set([])
         self.fund_index_map = self.fund_index_map or {}
+        self.stock_ipo_data = {}
+        self.conv_bond_ipo_data = {}
+        self.stock_ipo_data_detail = {}
+        self.conv_bond_ipo_data_detail = {}
+        self.stock_ipo_info = {}
+        self.conv_bond_ipo_info = {}
 
     def __repr__(self):
         s = '<DTS'
