@@ -20,6 +20,7 @@ from .etl_tool import S3RetrieverForDM
 from ..view.raw_models import CSIndexComponent
 from ..view.basic_models import *
 from ..view.derived_models import *
+from .combine_single_fac import combine_factor
 
 INDEX_REPLACE = {'active':'csi_stockfund',
                  'conv_bond':'csi_convex'}
@@ -61,6 +62,8 @@ class FundDataManager(DataManager):
         self._score_manager = score_manager or FundScoreManager()
         self.set_score_param(self._fund_score_param)
         self.fund_list_with_nav = set()
+        self.access_token_dic = {}
+
 
     @property
     def inited(self):
@@ -136,6 +139,7 @@ class FundDataManager(DataManager):
         return True
 
     def init(self, index_list=None, score_pre_calc=True, print_time=False, use_weekly_monthly_indicators=False, block_df_list=_BLOCK_DF_LIST):
+        
         if self._s3_retriever.is_activated:
             # Caution!! 这里应始终保持init传进来的参数与try_to_init_from_s3第一个参数相适应，以正确判断是否为默认配置
             # 如果init中的参数改成keyword类型，可以使用__kwdefaults__来帮助判断
@@ -487,6 +491,8 @@ class FundDataManager(DataManager):
             self.dts.fund_indicator = pd.merge(self.dts.fund_indicator, _fund_size,
                                             how='left', left_on=['fund_id','datetime'], right_on=['fund_id','datetime'])
             self.dts.fund_indicator['fund_size'] = self.dts.fund_indicator['fund_size'].fillna(0)
+            _single_fac_df = combine_factor()
+            self.dts.fund_indicator = pd.merge(self.dts.fund_indicator, _single_fac_df, how='left', on=['datetime','fund_id'])
             _tm_deriv_apply_manager_rank = time.time()
 
             if use_weekly_monthly_indicators:
@@ -731,6 +737,104 @@ class FundDataManager(DataManager):
         else:
             return self.dts.index_price.copy()
 
+    def is_update_local_data(self, api_name):
+        now = datetime.datetime.now()
+        access_token = self.access_token_dic.get(api_name, None)
+        if access_token is None or now > access_token:
+            return True
+        return False 
+    
+    def update_access_token(self, api_name):
+        now = datetime.datetime.now()
+        access_token = now + datetime.timedelta(hours=1)
+        self.access_token_dic[api_name] = access_token
+
+    def get_stock_ipo_data(self):
+        dt = datetime.datetime.now().date()
+        api_name = 'get_stock_ipo_data'
+        if self.is_update_local_data(api_name):
+            df = self.raw_data(func_name='get_em_stock_ipo_recent', dt=dt)
+            self.dts.stock_ipo_data[dt] = df
+            self.update_access_token(api_name)
+        else:
+            df = self.dts.stock_ipo_data.get(dt, None)
+        return dt ,df
+        
+    def get_conv_bond_ipo_data(self):
+        dt = datetime.datetime.now().date()
+        api_name = 'get_conv_bond_ipo_data'
+        if self.is_update_local_data(api_name):
+            df = self.raw_data(func_name='get_em_conv_bond_ipo_recent', dt=dt)
+            self.dts.conv_bond_ipo_data[dt] = df
+            self.update_access_token(api_name)
+        else:
+            df = self.dts.conv_bond_ipo_data.get(dt, None)
+        return dt ,df
+
+    def get_stock_ipo_data_detail(self):
+        dt = datetime.datetime.now().date()
+        api_name = 'get_stock_ipo_data_detail'
+        if self.is_update_local_data(api_name):
+            df = self.view_data(func_name='get_recent_stock_ipo')
+            self.dts.stock_ipo_data_detail[dt] = df
+            self.update_access_token(api_name)
+        else:
+            df = self.dts.stock_ipo_data_detail.get(dt, None)
+        return dt ,df
+
+    def get_conv_bond_ipo_data_detail(self):
+        dt = datetime.datetime.now().date()
+        api_name = 'get_conv_bond_ipo_data_detail'
+        if self.is_update_local_data(api_name):
+            df = self.view_data(func_name='get_recent_conv_bond_ipo')
+            self.dts.conv_bond_ipo_data_detail[dt] = df
+            self.update_access_token(api_name)
+        else:
+            df = self.dts.conv_bond_ipo_data_detail.get(dt, None)
+        return dt ,df
+
+    def get_stock_ipo_info(self):
+        dt = datetime.datetime.now().date()
+        api_name = 'get_stock_ipo_info'
+        if self.is_update_local_data(api_name):
+            df = self.raw_data(func_name='get_em_stock_ipo_info')
+            self.dts.stock_ipo_info[dt] = df
+            self.update_access_token(api_name)
+        else:
+            df = self.dts.stock_ipo_info.get(dt, None)
+        return dt ,df
+
+    def get_conv_bond_ipo_info(self):
+        dt = datetime.datetime.now().date()
+        api_name = 'get_conv_bond_ipo_info'
+        if self.is_update_local_data(api_name):
+            df = self.raw_data(func_name='get_em_conv_bond_ipo_info')
+            self.dts.conv_bond_ipo_info[dt] = df
+            self.update_access_token(api_name)
+        else:
+            df = self.dts.conv_bond_ipo_info.get(dt, None)
+        return dt ,df
+
+    def get_stock_ipo_sector_info(self, begin_date, end_date, sector):
+        dt, df = self.get_stock_ipo_info()
+        if sector == '申购':
+            df = df[(df['申购日期'] >= begin_date) & (df['申购日期'] <= end_date)].copy()
+        elif sector == '上市':
+            df = df[(df['上市日期'] >= begin_date) & (df['上市日期'] <= end_date)].copy()
+        elif sector == '公布中签':
+            df = df[(df['中签公布'] >= begin_date) & (df['中签公布'] <= end_date)].copy()
+        return df
+
+    def get_conv_bond_sector_info(self, begin_date, end_date, sector):
+        df, df = self.get_conv_bond_ipo_info()
+        if sector == '申购':
+            df = df[(df['申购日期'] >= begin_date) & (df['申购日期'] <= end_date)].copy()
+        elif sector == '上市':
+            df = df[(df['上市日期'] >= begin_date) & (df['上市日期'] <= end_date)].copy()
+        elif sector == '公布中签':
+            df = df[(df['中签公布'] >= begin_date) & (df['中签公布'] <= end_date)].copy()
+        return df
+
     def get_index_price_data(self, dt):
         _index_price = self.get_index_price(dt)
         return AssetPrice(**_index_price.to_dict())
@@ -809,6 +913,8 @@ class FundDataManager(DataManager):
         index_1 = fund_info.loc[pd.IndexSlice[:, desc_name], :].index.get_level_values(0).values[0]
         return fund_info.loc[index_1]
 
+    
+        
 def test():
     # m = FundDataManager('20190101', '20200101', score_manager=FundScoreManager())
     m = FundDataManager('20190101', '20200101')
