@@ -21,13 +21,25 @@ class FundDailyCollection(Base):
     datetime = Column(CHAR(20), primary_key=True)  # 时间
     order_book_id = Column(CHAR(20))  # 基金代码
 
+    # basic.fund_info
+    risk_level = Column(CHAR(2))  # 风险等级
+    full_name = Column(CHAR(255)) # 基金全名
+    currency = Column(CHAR(20)) # 币种
+    manage_fee = Column(DOUBLE(asdecimal=False)) # 管理费
+    trustee_fee = Column(DOUBLE(asdecimal=False)) # 托管费
+    purchase_fee = Column(DOUBLE(asdecimal=False)) # 申购费
+    redeem_fee = Column(DOUBLE(asdecimal=False)) # 赎回费
+    benchmark_1 = Column(CHAR(255)) # 业绩基准标的指数简称第一名
+    benchmark_2 = Column(CHAR(255)) # 业绩基准标的指数简称第二名
+    subscr_fee_detail = Column(TEXT) # 认购费率详情
+    purchase_fee_detail = Column(TEXT) # 申购费率详情
+    redeem_fee_detail = Column(TEXT) # 赎回费率详情
+    service_fee = Column(TEXT) # 销售服务费率
     wind_class_I = Column(CHAR(64))  # Wind基金类型  (混合型基金 债券型基金 股票型基金 货币市场型基金 国际(QDII)基金 另类投资基金)
     wind_class_II = Column(CHAR(64))  # Wind基金二级类型
     institution_rating = Column(CHAR(20))  # 机构评级 暂无
     found_to_now = Column(DOUBLE(asdecimal=False))  # 成立年限
-    average_size = Column(DOUBLE(asdecimal=False))  # 平均规模 basic.FundRet.avg_size
     exchange_status = Column(CHAR(20))  # 交易状态 basic.FundStatusLatest
-    theme = Column(CHAR(20))  # 基金主题 暂无
     track_index = Column(CHAR(20)) # 跟踪指数 basic.FundInfo.track_index
     purch_status = Column(CHAR(16))  # 申购状态 basic.FundStatusLatest
     redem_status = Column(CHAR(16))  # 赎回状态 basic.FundStatusLatest
@@ -36,23 +48,24 @@ class FundDailyCollection(Base):
     otc_lp_limit = Column(DOUBLE(asdecimal=False))  # 场外暂停大额申购上限
     otc_lp_limit_jg = Column(DOUBLE(asdecimal=False))  # 场外暂停大额申购上限(机构)
     otc_lp_limit_gr = Column(DOUBLE(asdecimal=False))  # 场外暂停大额申购上限(个人)
+    first_benchmark_name = Column(CHAR(128)) # 根据benchmark 信息拆出来的基准名字
 
     # basic.FundNav
-    unit_net_value = Column(DOUBLE(asdecimal=False))  # 单位净值 
+    unit_net_value = Column(DOUBLE(asdecimal=False))  # 单位净值
     acc_net_value = Column(DOUBLE(asdecimal=False))  # 累计单位净值
     adjusted_net_value = Column(DOUBLE(asdecimal=False))  # 复权净值
     change_rate = Column(DOUBLE(asdecimal=False))  # 日收益率
     found_date = Column(CHAR(20))  # 成立日期
     end_date = Column(CHAR(20))  # 关闭日期
-    
+
     # basic.FundRet
-    annualized_returns = Column(DOUBLE(asdecimal=False))  # 成立以来年化收益率 
-    annualized_risk = Column(DOUBLE(asdecimal=False))  # 成立以来年化风险 
-    information_ratio = Column(DOUBLE(asdecimal=False))  # 成立以来信息比率 
-    last_month_return = Column(DOUBLE(asdecimal=False))  # 近一月收益率 
-    last_six_month_return = Column(DOUBLE(asdecimal=False)) # 
+    annualized_returns = Column(DOUBLE(asdecimal=False))  # 成立以来年化收益率
+    annualized_risk = Column(DOUBLE(asdecimal=False))  # 成立以来年化风险
+    information_ratio = Column(DOUBLE(asdecimal=False))  # 成立以来信息比率
+    last_month_return = Column(DOUBLE(asdecimal=False))  # 近一月收益率
+    last_six_month_return = Column(DOUBLE(asdecimal=False)) #
     last_three_month_return = Column(DOUBLE(asdecimal=False))  # 近一季度收益率
-    last_twelve_month_return = Column(DOUBLE(asdecimal=False))  # 近一年收益率 
+    last_twelve_month_return = Column(DOUBLE(asdecimal=False))  # 近一年收益率
     last_week_return = Column(DOUBLE(asdecimal=False))  # 近一周收益率
     year_to_date_return = Column(DOUBLE(asdecimal=False))  # 今年以来收益率
     to_date_return = Column(DOUBLE(asdecimal=False))  # 成立至今收益率
@@ -79,7 +92,8 @@ class FundDailyCollection(Base):
     fund_manager_id = Column(CHAR(127))  # 基金经理ID
     company_name = Column(CHAR(64))  # 基金公司
     symbol = Column(CHAR(64)) # 基金名称
-    
+    manager_profit = Column(DOUBLE(asdecimal=False)) # 基金经理任期收益
+
     # basic.FundBenchmark
     benchmark = Column(CHAR(255)) # 业绩基准  basic.FundInfo.benchmark
     benchmark_s = Column(CHAR(64)) # 跟踪标的id
@@ -127,10 +141,15 @@ class FundDailyCollection(Base):
     var = Column(DOUBLE(asdecimal=False))  # 资产在险值
     r_square = Column(DOUBLE(asdecimal=False))  # 决定系数R方
     sharpe = Column(DOUBLE(asdecimal=False))  # 夏普率
+    downside_std = Column(DOUBLE(asdecimal=False))  # 下行风险
+    continue_regress_v = Column(DOUBLE(asdecimal=False))  # 收益稳定性
+    stock_cl_beta = Column(DOUBLE(asdecimal=False))  # 择时收益
+    stock_cl_alpha = Column(DOUBLE(asdecimal=False))  # 选股收益
+    prn_hold = Column(DOUBLE(asdecimal=False))  # 私人持有占比
 
     # derived.FundScoreNew
     tag_name = Column(CHAR(64)) # 基金类别
-    score = Column(DOUBLE(asdecimal=False)) # 评分
+    #score = Column(DOUBLE(asdecimal=False)) # 评分
 
     return_score = Column(DOUBLE(asdecimal=False))  # 被动指数型、被动指数型债券(均为二级分类)基金为跟踪标的能力，其他为收益能力
     robust_score = Column(DOUBLE(asdecimal=False))  # 稳定性能力
@@ -140,11 +159,28 @@ class FundDailyCollection(Base):
     team_score = Column(DOUBLE(asdecimal=False))  # 基金公司团队能力
     total_score = Column(DOUBLE(asdecimal=False), nullable=False)  # 总分
 
+    # fund recommend part
+    sector_list = Column(TEXT) # 板块列表 需要json.loads
+    sector_name = Column(TEXT) # 板块名字列表 需要json.loads
+    index_list = Column(TEXT) # 指数列表 需要json.loads
+    index_name = Column(TEXT) # 指数名字列表 需要json.loads
+    top_mng_id = Column(CHAR(64)) # 头名基金经理ID
+    top_mng_name = Column(CHAR(64)) # 头名基金经理名字
+    top_manager_profit = Column(DOUBLE(asdecimal=False)) # 头名基金经理任期收益
+    is_ipo_fund = Column(TINYINT(1)) # 是否是打新基金
+    is_abs_ret_fund = Column(TINYINT(1)) # 是否是绝对收益基金 0 否， 1 是
+    is_conv_bond_fund = Column(TINYINT(1)) # 是否是可转债基金 0 否， 1 是
+
+    # derived.style_box
+    fund_size_type = Column(CHAR(20)) # 基金规模类型
+    fund_style_type = Column(CHAR(20)) # 基金风格类型
+
     @staticmethod
     def trans_columns():
         return {
             'fund_id': '基金ID',
             'order_book_id': '基金代码',
+
             'wind_class_I': '基金类型',
             'wind_class_II': '二级分类',
             'symbol': '基金名称',
@@ -152,6 +188,7 @@ class FundDailyCollection(Base):
             'found_to_now': '成立年限',
             'average_size': '基金规模',
             'track_index': '跟踪指数',
+            'first_benchmark_name': '第一基准名',
 
             'exchange_status': '交易状态',
             'purch_status': '申购状态',
@@ -161,7 +198,6 @@ class FundDailyCollection(Base):
             'otc_lp_limit_jg': '场外暂停大额申购上限(机构)',
             'otc_lp_limit_gr': '场外暂停大额申购上限(个人)',
 
-            'theme': '基金主题',
             'adjusted_net_value': '复权净值',
             'unit_net_value': '净值',
             'acc_net_value': '累计净值',
@@ -200,6 +236,7 @@ class FundDailyCollection(Base):
             'year_to_date_return_rank': '年初至今同类排名',
             'to_date_return_rank': '成立以来同类排名',
             'group_num': '同类数量',
+            'manager_profit':'基金经理任期收益',
 
             'zs': '招商评级',
             'sh3': '上证三年评级',
@@ -238,9 +275,15 @@ class FundDailyCollection(Base):
             'var': '_资产在险值',
             'r_square': '_决定系数R方',
             'sharpe': '_夏普率',
+            'downside_std':'下行风险',
+            'continue_regress_v':'收益稳定性',
+            'stock_cl_beta':'择时收益',
+            'stock_cl_alpha':'选股收益',
+            'prn_hold':'私人持有占比',
 
             'tag_name': '基金类别',
-            'score': '基金评分',
+            'fund_size_type':'基金规模类别',
+            'fund_style_type':'基金风格类别',
 
             'return_score': '收益能力',
             'robust_score': '稳定性能力',
@@ -249,6 +292,31 @@ class FundDailyCollection(Base):
             'selection_score': '选证能力',
             'team_score': '团队能力',
             'total_score': '总分',
+
+            'sector_list': '板块列表',
+            'sector_name': '板块名字列表',
+            'index_list': '指数列表',
+            'index_name': '指数名字列表',
+            'top_mng_id': '头名基金经理ID',#
+            'top_mng_name': '头名基金经理名字',#
+            'top_manager_profit':'头名基金经理任期收益',#
+            'is_abs_ret_fund': '是否是绝对收益基金',
+            'is_conv_bond_fund': '是否是可转债基金',
+            'is_ipo_fund': '是否是打新基金',
+            'fund_type': '基金大类类型',
+            'risk_level':'风险等级',
+            'full_name':'基金全名',
+            'currency':'币种',
+            'manage_fee':'管理费',
+            'trustee_fee':'托管费',
+            'purchase_fee':'申购费',
+            'redeem_fee':'赎回费',
+            'benchmark_1':'业绩基准标的指数简称第一名',
+            'benchmark_2':'业绩基准标的指数简称第二名',
+            'subscr_fee_detail':'认购费率详情',
+            'purchase_fee_detail':'申购费率详情',
+            'redeem_fee_detail':'赎回费率详情',
+            'service_fee':'销售服务费率',
         }
 
 
@@ -317,7 +385,7 @@ class IndexDailyCollection(Base):
     total_turnover = Column(DOUBLE(asdecimal=False))  # 成交额
     ret = Column(DOUBLE(asdecimal=False))  # 收益率
     yest_close = Column(DOUBLE(asdecimal=False))  # 前收盘价
-    
+
     # basic.IndexInfo
     order_book_id = Column(CHAR(20))  # 米筐ID
     industry_tag = Column(CHAR(64))  # 行业标签
@@ -539,6 +607,7 @@ class FundRecommendationCollection(Base):
             'fund_type': '基金大类类型',
         }
 
+
 class ManagerInfoCollection(Base):
     """基金经理评价"""
 
@@ -547,4 +616,133 @@ class ManagerInfoCollection(Base):
     mng_id = Column(CHAR(10), primary_key=True) # 经理ID
     mng_name = Column(CHAR(30)) # 经理名
     introduction = Column(TEXT) # 介绍
-    fund_type = Column(CHAR(64)) # 基金大类类型
\ No newline at end of file
+    fund_type = Column(CHAR(64)) # 基金大类类型
+
+
+class StockIpoCollection(Base):
+    """股票打新数据"""
+
+    __tablename__ = 'stock_ipo_collection'
+
+    stock_code = Column(CHAR(10), primary_key=True) # 股票ID
+    stock_name = Column(CHAR(30)) # 股票名
+    trade_market = Column(CHAR(40)) # 交易板块
+    list_date = Column(DATE) # 上市日期
+    ipo_price = Column(DOUBLE(asdecimal=False)) # 发行价
+    latest_price = Column(DOUBLE(asdecimal=False)) # 最新价
+    latest_rate = Column(DOUBLE(asdecimal=False)) # 涨跌幅
+    cumulate_rate = Column(DOUBLE(asdecimal=False)) # 累计涨幅
+    first_date_rate = Column(DOUBLE(asdecimal=False)) # 首日涨幅
+    continue_limited_rise = Column(DOUBLE(asdecimal=False)) # 连续涨停
+    earn_per_stick = Column(DOUBLE(asdecimal=False)) # 每签获利
+
+    @staticmethod
+    def trans_columns():
+        return {
+            'stock_code': '股票ID',
+            'stock_name': '股票名',
+            'trade_market': '交易板块',
+            'list_date': '上市日期',
+            'ipo_price': '发行价',
+            'latest_price': '最新价',
+            'latest_rate': '涨跌幅',
+            'cumulate_rate': '累计涨幅',
+            'first_date_rate': '首日涨幅',
+            'continue_limited_rise': '连续涨停',
+            'earn_per_stick': '每签获利',
+        }
+
+class ConvBondIpoCollection(Base):
+    '''可转债券打新数据'''
+
+    __tablename__ = 'conv_bond_collection'
+
+    bond_id = Column(CHAR(10), primary_key=True) # 可债ID
+    bond_name = Column(CHAR(30)) # 债券名字
+    list_date = Column(DATE) # 上市日期
+    ipo_price = Column(DOUBLE(asdecimal=False)) # 发行价
+    trade_market = Column(CHAR(5)) # 市场名字
+    new_price = Column(DOUBLE(asdecimal=False)) # 最新价
+    total_ret = Column(DOUBLE(asdecimal=False)) # 累计涨幅
+    first_open = Column(DOUBLE(asdecimal=False)) # 首日开盘价
+    earn_per_account = Column(DOUBLE(asdecimal=False)) # 单账户收益
+    earn_per_stick = Column(DOUBLE(asdecimal=False)) # 单签收益
+    first_date_rate = Column(DOUBLE(asdecimal=False)) # 首日涨幅
+    rate = Column(DOUBLE(asdecimal=False)) # 中签率
+    limit_num = Column(DOUBLE(asdecimal=False)) # 认购数量上限
+
+    @staticmethod
+    def trans_columns():
+        return {
+            'bond_id': '可转债ID',
+            'bond_name': '债券名字',
+            'list_date': '上市日期',
+            'ipo_price': '发行价',
+            'trade_market': '市场代码',
+            'new_price':'最新价',
+            'total_ret': '累计涨幅',
+            'first_open': '首日开盘价',
+            'first_date_rate': '首日涨幅',
+            'earn_per_account': '单账户收益',
+            'earn_per_stick': '每签获利',
+            'rate':'中签率',
+            'limit_num':'认购数量上限',
+        }
+
+
+class FundManagerDailyCollection(Base):
+    """基金经理数据"""
+
+    __tablename__ = 'fund_manager_daily_collection'
+
+    
+    mng_id = Column(CHAR(10), primary_key=True) # 基金经理id
+    fund_type = Column(CHAR(20), primary_key=True) # 基金类型
+    name = Column(CHAR(25)) # 姓名
+    profit = Column(DOUBLE(asdecimal=False)) # 任期收益
+    mdd_history_daily = Column(DOUBLE(asdecimal=False)) # 历史最大回撤
+    annual_ret_history_m = Column(DOUBLE(asdecimal=False)) # 历史年化收益
+    total_score = Column(DOUBLE(asdecimal=False)) # 经理总分
+    ret_ability = Column(DOUBLE(asdecimal=False)) # 收益能力
+    risk_ability = Column(DOUBLE(asdecimal=False)) # 抗风险能力
+    select_time = Column(DOUBLE(asdecimal=False)) # 择时能力
+    select_stock = Column(DOUBLE(asdecimal=False)) # 选股能力
+    stable_ability = Column(DOUBLE(asdecimal=False)) # 稳定能力
+    experience = Column(DOUBLE(asdecimal=False)) # 经验能力
+    mdd_5y_m = Column(DOUBLE(asdecimal=False)) # 近五年最大回撤
+    annual_ret_5y_m = Column(DOUBLE(asdecimal=False)) # 近五年年化收益
+    mdd_3y_m = Column(DOUBLE(asdecimal=False)) # 近三年最大回撤
+    annual_ret_3y_m = Column(DOUBLE(asdecimal=False)) # 近三年年化收益
+    mdd_1y_m = Column(DOUBLE(asdecimal=False)) # 近一年最大回撤
+    annual_ret_1y_m = Column(DOUBLE(asdecimal=False)) # 近一年年化收益
+    trading_days = Column(DOUBLE(asdecimal=False)) # 从业天数
+    best_fund = Column(CHAR(10)) # 代表作品
+    company_id = Column(CHAR(64)) # 基金公司
+
+
+    @staticmethod
+    def trans_columns():
+        return {
+            'mng_id':'基金经理id',
+            'name':'姓名',
+            'fund_type':'基金类型',
+            'profit':'任期收益',
+            'mdd_history_daily':'历史最大回撤',
+            'annual_ret_history_m':'历史年化收益',
+            'total_score':'经理总分',
+            'ret_ability':'收益能力',
+            'risk_ability':'抗风险能力',
+            'select_time':'择时能力',
+            'select_stock':'选股能力',
+            'stable_ability':'稳定能力',
+            'experience':'经验能力',
+            'mdd_5y_m':'近五年最大回撤',
+            'annual_ret_5y_m':'近五年年化收益',
+            'mdd_3y_m':'近三年最大回撤',
+            'annual_ret_3y_m':'近三年年化收益',
+            'mdd_1y_m':'近一年最大回撤',
+            'annual_ret_1y_m':'近一年年化收益',
+            'trading_days':'从业天数',
+            'best_fund':'代表作品',
+            'company_id':'基金公司',
+        }
\ No newline at end of file
