@@ -10,6 +10,7 @@ from functools import partial
 import statsmodels.api as sm
 from statsmodels.tsa.ar_model import AutoReg
 from scipy.stats import kurtosis, skew
+from decimal import Decimal, ROUND_HALF_UP, Context
 
 class CalculatorBase:
 
@@ -17,6 +18,13 @@ class CalculatorBase:
     TOTAL_DAYS_PER_YEAR = 365
     TOTAL_WEEKS_PER_YEAR = 52
     TOTAL_MONTHS_PER_YEAR = 12
+    STOCK_IPO_NUM_MARKET = {
+        '深交所中小板': 500,
+        '深交所创业板': 500,
+        '上交所主板': 1000,
+        '上交所科创板': 500,
+        '深交所主板': 500,
+    }
 
     @staticmethod
     def calc_cl_alpha_beta(total: np.ndarray):
@@ -30,13 +38,20 @@ class CalculatorBase:
         if np.count_nonzero(X[:, 1]) == 0:
             return {'beta':np.nan,
                     'alpha':np.nan,
+                    'beta_bull':np.nan,
+                    'beta_bear':np.nan,
+                    
                     }
         est2 = sm.OLS(total[:, 0], sm.add_constant(X, prepend=False)).fit()
         return {'beta':est2.params[0] - est2.params[1],
-                'alpha':est2.params[-1]}
+                'alpha':est2.params[-1],
+                'beta_bull':est2.params[0],
+                'beta_bear':-est2.params[1],
+                }
     
     @staticmethod
     def calc_hm_alpha_beta(total: np.ndarray):
+        # 牛市追踪 市场上涨是alpha
         if total.shape[0] <= 1:
             return {'beta':np.nan,
                     'alpha':np.nan,
@@ -48,6 +63,12 @@ class CalculatorBase:
                 'alpha':est2.params[-1],
                 }
 
+    @staticmethod
+    def stat_round_pct(x):
+        s = str(round(100*x,2))
+        s = s[::-1].zfill(4)[::-1]
+        return s + '%'
+
     @staticmethod
     def calc_continue_regress_v(monthly_ret, risk_free_rate):
         # 半年周期
@@ -145,7 +166,7 @@ class CalculatorBase:
                 mdd_date2 = mdd_part.idxmin()
                 mdd_date1 = sr[:mdd_date2].idxmax()
                 mdd_lens = (mdd_date2-mdd_date1).days
-            calmar = (annual_ret - risk_free_rate) / mdd
+            calmar = (annual_ret - risk_free_rate) / mdd if mdd != 0 else 0
             sr_ret_no_risk_free = sr_ret - risk_free_rate / period_1y
             downside_risk = np.minimum(sr_ret_no_risk_free,0).std(ddof=1) * np.sqrt(period_1y)
             sortino = (annual_ret - risk_free_rate) / downside_risk
@@ -174,6 +195,8 @@ class CalculatorBase:
                 cl_res = CalculatorBase.calc_cl_alpha_beta(df_ret_risk_free.to_numpy())
                 alpha_cl = cl_res['alpha'] * period_1y
                 beta_cl = cl_res['beta']
+                beta_bear = cl_res['beta_bear']
+                beta_bull = cl_res['beta_bull']
                 hm_res = CalculatorBase.calc_hm_alpha_beta(df_ret_risk_free.to_numpy())
                 alpha_hm = hm_res['alpha'] * period_1y
                 beta_hm = hm_res['beta']
@@ -248,6 +271,8 @@ class CalculatorBase:
                     'kurtosis':kurtosis_value,
                     'alpha_cl':alpha_cl,
                     'beta_cl':beta_cl,
+                    'beta_bear':beta_bear,
+                    'beta_bull':beta_bull,
                     'alpha_hm':alpha_hm,
                     'beta_hm':beta_hm,
                     'excess_ret':excess_ret,
@@ -338,6 +363,8 @@ class CalculatorBase:
                     'kurtosis':0,
                     'alpha_cl':0,
                     'beta_cl':0,
+                    'beta_bear':0,
+                    'beta_bull':0,
                     'alpha_hm':0,
                     'beta_hm':0,
                     'excess_ret':0,
@@ -355,3 +382,163 @@ class CalculatorBase:
                     'excess_ret_cotinue':0,
                     'continue_value_m':0,
                 }
+
+    @staticmethod
+    def simulated_mv_calc(df,fee_dic,weight_dic):
+        '''
+        df structure: 
+                    index   : datetime
+                    column  : different assets mv
+        i.g.
+
+                	A	    B	    C	    D	    E
+        2020-03-02	1.2047	1.0858	1.4002	1.0482	1.000
+        2020-03-06	1.2156	1.0983	1.4211	1.0496	1.005
+        
+        mng_fee_dic: 
+        i.g.            
+            fee_dic = {'A':0.2,'B':0.2,'C':0.2,'D':0.2,'E':0.2}
+        
+        weight_dic: value or weight 
+        i.g.
+            weight_dic = {'A':1,'B':1,'C':1,'D':1,'E':1}
+
+        '''
+        # 归一化
+        df_to_1 = df / df.iloc[0]
+        # 盈利
+        excess_ret = (df_to_1 - 1)
+        # 盈 或 亏
+        earn_con = (excess_ret > 0) * 1
+        # 费
+        pay_mng_fee = excess_ret * earn_con * pd.DataFrame([fee_dic]).values
+        # 净值
+        simu_nav = df_to_1
+        simu_nav_vir = df_to_1 - pay_mng_fee
+        # 真实总净值
+        simu_nav_total = pd.DataFrame((simu_nav*pd.DataFrame([weight_dic]).values).sum(axis=1))
+        # 虚拟总净值
+        simu_nav_vir_total = pd.DataFrame((simu_nav_vir*pd.DataFrame([weight_dic]).values).sum(axis=1))
+        simu_nav_total.columns = ['mv']
+        simu_nav_vir_total.columns = ['mv']
+        return simu_nav_vir_total, simu_nav_total
+
+    @staticmethod
+    def df_data_select(df, start_date, end_date, cols, resample_method, drop_col_title):
+        # 组合净值分析时 净值选取
+        # 设置 起始日 截止日 选取列名 对列共同名字是否去掉
+        if end_date is None:
+            end_date = datetime.date(2040,1,1)
+        if start_date is None:
+            start_date = datetime.date(2010,1,1)
+        if cols is not None:
+            df = df[cols]
+        df = CalculatorBase.data_resample(df.loc[start_date:end_date], resample_method, drop_col_title)
+        return df
+
+    @staticmethod
+    def data_resample(df, resample_method, drop_col_title=True):
+        COL_TITLE = '融智'
+        if resample_method == '1D':
+            return df 
+        if drop_col_title:
+            cols = df.columns.tolist()
+            cols = [i.replace(COL_TITLE,'') for i in cols]
+            df.columns = cols
+        df = df.set_axis(pd.to_datetime(df.index), inplace=False).resample(resample_method).last()
+        df.index = [i.date() for i in df.index]
+        df.index.name = 'datetime'
+        return df.ffill()
+
+    @staticmethod
+    def proper_round(num, dec=0):
+        dec = Decimal(10) ** -dec
+        return float(Decimal(str(num)).quantize(dec, context=Context(rounding=ROUND_HALF_UP)))
+
+    @staticmethod
+    def stock_ipo_continue_up_limit(    dates:  pd.core.series.Series,
+                                        values: pd.core.series.Series,
+                                        ipo_price: float,
+                                        list_date: datetime.date,
+                                        ipo_date: datetime.date,
+                                        trade_market: str,
+                                        stock_name: str,
+                                        stock_code: str):
+        dates = pd.to_datetime(dates)
+        dates = [i.date() for i in dates]
+        assert len(dates) == len(values), 'date and port_values has different numbers'
+        df = pd.DataFrame(values, index=dates).sort_index().dropna()
+        col = 'price'
+        df.columns = [col]
+        rate = [1.44] + df.shape[0] * [1.1]
+        df.loc[ipo_date,col] = ipo_price
+        df = df.sort_index()
+        if trade_market in ['上交所主板','深交所中小板']:
+            df.loc[:,'limit_price'] = (df.price * rate).map(lambda x: CalculatorBase.proper_round(x,2)).shift(1)
+            df.loc[:,'limit_con'] = (df.limit_price == df.price) * 1  
+            limit_list = df.limit_con.iloc[1:].tolist()
+            if 0 not in limit_list:
+                ipo_lens = len(limit_list)
+            else:
+                ipo_lens = limit_list.index(0)
+            num = CalculatorBase.STOCK_IPO_NUM_MARKET[trade_market]
+            earning_per_stick = int(round((df.price.values[ipo_lens] - df.price.values[0]) * num))
+        else:
+            ipo_lens = np.nan
+            earning_per_stick = np.nan
+        res = {
+            'stock_code':stock_code,
+            'stock_name':stock_name,
+            'trade_market':trade_market,
+            'list_date':list_date,
+            'ipo_price':ipo_price,
+            'latest_price':df.price.values[-1],
+            'latest_rate':df.price.pct_change(1).values[-1],
+            'cumulate_rate':df.price.values[-1] / df.price.values[0] - 1,
+            'first_date_rate':df.price.values[1] / df.price.values[0] - 1,
+            'continue_limited_rise':ipo_lens,
+            'earn_per_stick':earning_per_stick,
+        }
+        return res
+
+    @staticmethod
+    def conv_bond_ipo_result(   bond_id:str,
+                                bond_name:str,
+                                list_date:datetime.date,
+                                ipo_price:float,
+                                dates:pd.core.series.Series,
+                                close_values:pd.core.series.Series,
+                                open_values:pd.core.series.Series,
+                                rate:float,
+                                limit_num:str):
+
+        rate = rate / 100
+        dates = pd.to_datetime(dates)
+        dates = [i.date() for i in dates]
+        assert len(dates) == len(close_values), 'date and port_values has different numbers'
+        assert len(dates) == len(open_values), 'date and port_values has different numbers'
+        df = pd.DataFrame({'close':close_values,'open':open_values}, index=dates).sort_index().dropna()
+        limit_num = int(limit_num.split('网上申购数量上限：')[1].split('手')[0])
+        trade_market = bond_id.split('.')[1]
+        new_price = df.close[-1]
+        total_ret = df.close[-1] / ipo_price - 1
+        first_open = df.open[0]
+        first_date_rate = df.close[0] / 100 - 1
+        earn_per_stick = (first_open - ipo_price) * 10
+        earn_per_account = earn_per_stick * limit_num * rate
+        res = {
+            'bond_id':bond_id,
+            'bond_name':bond_name,
+            'list_date':list_date,
+            'ipo_price':ipo_price,
+            'trade_market':trade_market,
+            'new_price':new_price,
+            'total_ret':total_ret,
+            'earn_per_account':earn_per_account,
+            'earn_per_stick':earn_per_stick,
+            'first_date_rate':first_date_rate,
+            'first_open':first_open,
+            'rate':rate,
+            'limit_num':limit_num,
+        }
+        return res
\ No newline at end of file
